@@ -1,16 +1,13 @@
 #!/usr/bin/perl
 
 print <<EOF;
-// THIS IS A GENERATED FILE, RUN callback.pl to regenerate it
-// THIS IS A GENERATED FILE, RUN callback.pl to regenerate it
-// THIS IS A GENERATED FILE, RUN callback.pl to regenerate it
-// THIS IS A GENERATED FILE, RUN callback.pl to regenerate it
-// THIS IS A GENERATED FILE, RUN callback.pl to regenerate it
-// THIS IS A GENERATED FILE, RUN callback.pl to regenerate it
+// THIS IS A GENERATED FILE: RUN callback.pl to regenerate it
+// THIS IS A GENERATED FILE: callback.pl is part of the GVPE
+// THIS IS A GENERATED FILE: distribution.
 
 /*
     callback.h -- C++ callback mechanism
-    Copyright (C) 2003 Marc Lehmann <pcg\@goof.com>
+    Copyright (C) 2003-2005 Marc Lehmann <pcg\@goof.com>
  
     This file is part of GVPE.
 
@@ -26,7 +23,7 @@ print <<EOF;
  
     You should have received a copy of the GNU General Public License
     along with gvpe; if not, write to the Free Software
-    Foundation, Inc. 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc. 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef CALLBACK_H__
