@@ -16,7 +16,7 @@
  
     You should have received a copy of the GNU General Public License
     along with gvpe; if not, write to the Free Software
-    Foundation, Inc. 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc. 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef GVPE_CONNECTION_H__
@@ -70,8 +70,9 @@ struct vpn_packet : hmac_packet
       PT_PING, PT_PONG,	// wasting namespace space? ;)
       PT_AUTH_REQ,	// authentification request
       PT_AUTH_RES,	// authentification response
-      PT_CONNECT_REQ,	// want other host to contact me
+      PT_CONNECT_REQ,	// want other node to contact me
       PT_CONNECT_INFO,	// request connection to some node
+      PT_DATA_BRIDGED,  // uncompressed packet with foreign mac pot. larger than path mtu
       PT_MAX
     };
 
@@ -117,6 +118,7 @@ enum
   {
     FEATURE_COMPRESSION = 0x01,
     FEATURE_ROHC        = 0x02,
+    FEATURE_BRIDGING    = 0x04,
   };
 
 struct connection
@@ -173,7 +175,8 @@ struct connection
     void recv_vpn_packet (vpn_packet *pkt, const sockinfo &rsi);
     void send_vpn_packet (vpn_packet *pkt, const sockinfo &si, int tos = 0);
 
-    void script_node ();
+    void script_init_env (const char *ext);
+    void script_init_connect_env ();
     const char *script_node_up ();
     const char *script_node_down ();
 
